@@ -3,25 +3,65 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0801';
 
+my %VALID_IMPORT_OPT = map{ $_ => 1 } qw( base mixin );
 sub import{
+    my ( $self, @opts ) = @_;
+    @opts = %{ $opts[0] } if ref $opts[0] eq 'HASH';
+    
+    # import option
+    my $import_opt = {};
+    while( my ( $opt, $val ) = splice( @opts, 0, 2 ) ){
+        croak "Invalid import option '$opt'" unless $VALID_IMPORT_OPT{ $opt };
+        $import_opt->{ $opt } = $val;
+    }
+    
     my $caller_pkg = caller;
     
+    # export function
     {
         # export function
         no strict 'refs';
         *{ "${caller_pkg}::ac" } = \&Simo::ac;
-        
-        # caller inherit Simo
-        push @{ "${caller_pkg}::ISA" }, __PACKAGE__;
     }
+    
+    # caller package inherit these classes
+    # 1.base class,  2.Simo,  3.mixin class
+    
+    _SIMO_inherit_classes( $caller_pkg, $import_opt->{ base }, $import_opt->{ mixin } );
 
     # auto strict and warnings
     strict->import;
     warnings->import;
 }
 
+# callar package inherit some classes
+sub _SIMO_inherit_classes{
+    my ( $pkg, $base, $mixin ) = @_;
+    
+    my @classes;
+    if( $base ){
+        push @classes,
+            ref $base eq 'ARRAY' ? @{ $base } : $base;
+    }
+    
+    push @classes, 'Simo';
+    
+    if( $mixin ){
+        push @classes,
+            ref $mixin eq 'ARRAY' ? @{ $mixin } : $mixin;
+    }
+    
+    foreach my $class( @classes ){
+        croak "Invalid class name '$class'" unless $class =~ /^(\w+::)*\w+$/;
+    }
+    
+    eval "package $pkg;" .
+         "use base \@classes;";
+    if( $@ ){ $@ =~ s/\s+at .+$//; croak $@ }
+}
+
 sub new{
     my ( $proto, @args ) = @_;
 
@@ -37,12 +77,21 @@ sub new{
     # set args
     while( my ( $attr, $val ) = splice( @args, 0, 2 ) ){
         croak "Invalid key '$attr' is passed to new" unless $self->can( $attr );
+        
         no strict 'refs';
         $self->$attr( $val );
     }
+    
+    foreach my $required_attrs ( $self->REQUIRED_ATTRS ){
+        croak "Attr '$required_attrs' is required." 
+            unless exists $self->{ $required_attrs };
+    }
     return $self;
 }
 
+# required keys when object is created by new.
+sub REQUIRED_ATTRS{ () }
+
 # get value specify attr names
 sub get_attrs{
     my ( $self, @attrs ) = @_;
@@ -86,6 +135,46 @@ sub set_attrs{
     return $self;
 }
 
+# run methods
+sub run_methods{
+    my ( $self, @method_or_args_list ) = @_;
+    
+    my $method_infos = $self->_SIMO_parse_run_methods_args( @method_or_args_list );
+    while( my $method_info = shift @{ $method_infos } ){
+        my ( $method, $args ) = @{ $method_info }{ qw( name args ) };
+        
+        if( @{ $method_infos } ){
+            $self->$method( @{ $args } );
+        }
+        else{
+            return wantarray ? ( $self->$method( @{ $args } ) ) :
+                                 $self->$method( @{ $args } );
+        }
+    }
+}
+
+sub _SIMO_parse_run_methods_args{
+    my ( $self, @method_or_args_list ) = @_;
+    
+    my $method_infos = [];
+    while( my $method_or_args = shift @method_or_args_list ){
+        croak "$method_or_args is bad. Method name must be string and args must be array ref"
+            if ref $method_or_args;
+        
+        my $method = $method_or_args;
+        croak "$method is not exist" unless $self->can( $method );
+        
+        my $method_info = {};
+        $method_info->{ name } = $method;
+        $method_info->{ args } = ref $method_or_args_list[0] eq 'ARRAY' ?
+                                 shift @method_or_args_list :
+                                 [];
+        
+        push @{ $method_infos }, $method_info;
+    }
+    return $method_infos;
+}
+
 
 # create accessor
 sub ac(@){
@@ -212,9 +301,12 @@ sub _SIMO_create_accessor{
         $e .=
         qq/        foreach my \$constrain ( \@{ \$ac_opt->{ constrain } } ){\n/ .
         qq/            local \$_ = \$val;\n/ .
+        qq/            \$@ = undef;\n/ .
         qq/            my \$ret = \$constrain->( \$val );\n/ .
-        qq/            Carp::croak( "Illegal value \$val is passed to ${pkg}::$attr" )\n/ .
-        qq/                unless \$ret;\n/ .
+        qq/            if( !\$ret ){\n/ .
+        qq/                \$@ ||= 'must be valid value.';\n/ .
+        qq/                Carp::croak( "${pkg}::$attr \$@" )\n/ .
+        qq/            }\n/ .
         qq/        }\n\n/;
     }
     
@@ -295,7 +387,7 @@ Simo - Very simple framework for Object Oriented Perl.
 
 =head1 VERSION
 
-Version 0.0601
+Version 0.0801
 
 =cut
 
@@ -601,6 +693,30 @@ or
 return value is $self. so method chaine is available
 
     $book->set_attrs( title => 'Simple OO', author => 'kimoto' )->some_method;
+    
+=head2 run_methods
+
+this excute some methods continuously.
+
+    my $result = $book_list->run_methods(
+        'select' => [ type => 'Commic' ],
+        'sort' => [ 'desc' },
+        'get_result'
+    );
+    
+args must be array ref. You can omit args.
+
+You can get last method return value in scalar context or list context.
+
+=head2 REQUIRED_ATTRS
+
+this method is expected to override.
+
+You can set required attrs when object is create by new.
+
+    sub REQUIRED_ATTRS{ qw( title author price ) }
+
+Please be careful not to write wrong spell.
 
 =head1 MORE TECHNIQUES
 
